package com.qihoo360.mobilesafe.extension

import android.content.Context
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import com.qihoo360.mobilesafe.support.log.Logger

/**
 * View的创建
 */
inline fun <reified view : View> Context.v(init :view.()-> Unit) :view{
    val conStr = view::class.java.getConstructor(Context::class.java)
    val view = conStr.newInstance(this)
    view.init()
    return view
}

/**
 * ViewGroup的创建
 */
inline fun <reified V:View> ViewGroup.v(init : V.() -> Unit):V{
    val conStr = V::class.java.getConstructor(Context::class.java)
    val view = conStr.newInstance(context)
    addView(view)
    view.init()
    return view
}


fun Context.toast(content:String){
    Toast.makeText(this,content,Toast.LENGTH_SHORT).show()
}


fun View.onClick(listener: View.OnClickListener?) :View{
    listener?.let {
        setOnClickListener(it)
    }
    return this
}

fun View.onClick(method :() -> Unit) : View {
    setOnClickListener{
        method()
    }
    return this
}

fun View.setVisible(visible :Boolean){
    this.visibility = if(visible) View.VISIBLE else View.GONE
}


inline fun  tryCatch(catchBlock: (Throwable)-> Unit = {},tryBlock: () -> Unit){
    try {
        tryBlock()
    }catch (e:Throwable){
        if(Logger.bDebug()){
            e.printStackTrace()
        }
        catchBlock(e)
    }finally {

    }
}


