package com.qihoo360.mobilesafe.reward.utils

import android.app.Activity
import android.content.Context
import android.content.Intent
import android.content.pm.PackageManager
import android.text.TextUtils
import com.qihoo360.apullsdk.apull.protocol.ApullReportManager
import com.qihoo360.apullsdk.apull.protocol.model.ApullTemplateBase
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullApp
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullMv
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateApullTouTiao
import com.qihoo360.apullsdk.apull.protocol.model.impl.TemplateGdt
import com.qihoo360.apullsdk.apull.protocol.model.impl.app.ApullAppItem
import com.qihoo360.apullsdk.apull.protocol.model.impl.gdt.ApullGdtItem
import com.qihoo360.apullsdk.apull.protocol.model.impl.mv.ApullMvItem
import com.qihoo360.apullsdk.apull.protocol.model.impl.toutiao.ApullTouTiaoItem
import com.qihoo360.apullsdk.apull.protocol.network.report.ReportNetworkTouTiao
import com.qihoo360.apullsdk.apull.view.utils.ApullCmdHandle
import com.qihoo360.mobilesafe.reward.data.ApullItemWrapper
import com.qihoo360.mobilesafe.support.log.Logger
import com.qihoo360.i.Factory
import com.qihoo360.i.IPluginManager
import com.qihoo360.mobilesafe.RewardSDK
import com.qihoo360.mobilesafe.extension.tryCatch



class RewardCmdHandle {
    
    companion object {

        const val TAG = "RewardCmdHandle"

        private fun openAppTypeApp(context: Context?, apullAppItem: ApullAppItem?, templateApullApp: TemplateApullApp?): Boolean {

            if (context == null || apullAppItem == null || templateApullApp == null) {
                return false
            }

            var applyResult = ApullCmdHandle.applyCmd(context,
                    apullAppItem.ad_extra_info, templateApullApp, apullAppItem)

            Logger.d(TAG, "openAppTypeApp: applyCmd:$applyResult")

            if (!applyResult) {
                applyResult = openAppWithCustom(context, apullAppItem.pkgname)
                Logger.d(TAG, "openAppTypeApp: openAppWithCustom:$applyResult")
            }

            return applyResult
        }

        fun openMvTypeApp(context: Context?, apullMvItem: ApullMvItem?, templateApullMv: TemplateApullMv?): Boolean {

            if (context == null || apullMvItem == null || templateApullMv == null) {
                return false
            }

            var handled: Boolean

            handled = handleDeepLink(context, apullMvItem)

            Logger.d(TAG, "openMvTypeApp handleDeepLink:$handled")

            if (!handled && !apullMvItem.auto_extra_info_ui.isNullOrEmpty()) {
                handled = ApullCmdHandle.applyCmd(context, apullMvItem.auto_extra_info_ui, templateApullMv, apullMvItem)
                Logger.d(TAG, "openMvTypeApp auto_extra_info_ui:$handled")
            }

            if (!handled && !apullMvItem.package_name.isNullOrEmpty()) {
                handled = openAppWithCustom(context, apullMvItem.package_name)
                Logger.d(TAG, "openMvTypeApp openAppWithCustom:$handled")
            }
            return handled
        }

        private fun openGDTTypeApp(context: Context?, apullGdtItem: ApullGdtItem?, templateGdt: TemplateGdt?): Boolean {
            if (context == null || apullGdtItem == null || templateGdt == null)
                return false

            var handled = false
            if (!TextUtils.isEmpty(apullGdtItem.pkgname)) {
                handled = openAppWithCustom(context, apullGdtItem.pkgname)
                Logger.d("openGDTTypeApp openAppWithCustom:$handled")
            }
            return handled
        }

        private fun openTouTiaoTypeApp(context:Context?,apullTouTiaoItem: ApullTouTiaoItem?,templateApullTouTiao: TemplateApullTouTiao?):Boolean{
            if (context == null || apullTouTiaoItem == null || templateApullTouTiao == null)
                return false
            var handled = false

            if (!TextUtils.isEmpty(apullTouTiaoItem.auto_extra_info_ui)) {
                handled = ApullCmdHandle.applyCmd(context, apullTouTiaoItem.auto_extra_info_ui, apullTouTiaoItem.package_name, templateApullTouTiao)
                Logger.d("openTouTiaoTypeApp auto_extra_info_ui:$handled")
            }

            if (!handled && !TextUtils.isEmpty(apullTouTiaoItem.package_name)) {
                handled = openAppWithCustom(context,apullTouTiaoItem.package_name)
                Logger.d(TAG, "openTouTiaoTypeApp openAppWithCustom:$handled")

            }
            return handled
        }

        fun openAllTypeApp(context: Context?, templateBase: ApullTemplateBase?): Boolean {
            var handled = false
            if (context == null || templateBase == null) {
                return handled
            }
            val apullItemWrapper = ApullItemWrapper(templateBase)
            when {
                apullItemWrapper.getProtocolType() == ApullItemWrapper.APP -> {
                    if (templateBase is TemplateApullApp) {
                        if (!templateBase.click_reported) {
                            templateBase.click_reported = true
                            ApullReportManager.reportApullSspAppClick(context, templateBase)
                            ApullReportManager.reportApullDjAppClick(context, templateBase)
                        }
                        if (!templateBase.opened_reported) {
                            templateBase.opened_reported = true
                            ApullReportManager.reportApullSspAppOpened(context, templateBase)
                        }


                        handled = openAppTypeApp(context, apullItemWrapper.getDefaultItem(false) as? ApullAppItem?, templateBase)
                    }
                }
                apullItemWrapper.getProtocolType() == ApullItemWrapper.MV -> {
                    if (templateBase is TemplateApullMv) {
                        // 数据上报
                        ApullReportManager.reportApullMvClick(context, templateBase)
                        ApullReportManager.reportApullSspMvClick(context, templateBase)
                        ApullReportManager.reportApullSspMvOpened(context, templateBase)
                        handled = openMvTypeApp(context, apullItemWrapper.getDefaultItem(false) as? ApullMvItem, templateBase)
                    }
                }
                apullItemWrapper.getProtocolType() == ApullItemWrapper.GDT -> {
                    if (templateBase is TemplateGdt) {
                        ApullReportManager.reportApullSspClick(context, templateBase)
                        ApullReportManager.reportApullSspOpened(context, templateBase)
                        handled = openGDTTypeApp(context, apullItemWrapper.getDefaultItem(false) as? ApullGdtItem?, templateBase)
                    }
                }

                apullItemWrapper.getProtocolType() == ApullItemWrapper.TOUTIAO -> {
                    if(templateBase is TemplateApullTouTiao){
                        ApullReportManager.reportApullTouTiao(context, templateBase, ReportNetworkTouTiao.REPORTTYPE.CLICK, 0)
                        ApullReportManager.reportApullSspClick(context, templateBase)
                        ApullReportManager.reportApullSspOpened(context, templateBase)
                        handled = openTouTiaoTypeApp(context,apullItemWrapper.getDefaultItem(false) as? ApullTouTiaoItem,templateBase)
                    }
                }
            }
            return handled
        }

        fun openAppWithCustom(context: Context, packageName: String): Boolean {
            var handled = false

            if (!TextUtils.isEmpty(packageName)) {
                tryCatch {
                    var intent: Intent? = Intent()
                    val packageManager = context.packageManager
                    intent = packageManager.getLaunchIntentForPackage(packageName)
                    intent!!.flags = (Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_RESET_TASK_IF_NEEDED
                            or Intent.FLAG_ACTIVITY_CLEAR_TOP)
                    context.startActivity(intent)
                    Logger.d(TAG, "openAppWithCustom package_name:$packageName")
                    handled = true
                }

            }
            return handled
        }

        fun handleDeepLink(context: Context?, apullMvItem: ApullMvItem?): Boolean {
            if (context == null)
                return false

            var handled = false
            if (!apullMvItem?.interaction_object?.deeplink.isNullOrEmpty()) {
                handled = handleGo2DeepLink(context, apullMvItem?.interaction_object?.deeplink, apullMvItem?.deeplink_pkgname)
                Logger.d(TAG, "handleDeepLink:$handled")
            }

            return handled
        }

        fun openAppWithSysWebView(context: Context?, item: ApullMvItem?) {
            openAppWithSysWebView(context, item?.interaction_object?.url)
        }

        private fun openAppWithSysWebView(context: Context?, url: String?) {
            if (!url.isNullOrEmpty()) {
                val intentBrowse = Intent(Intent.ACTION_VIEW)
                val flags = (Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_RESET_TASK_IF_NEEDED) or Intent.FLAG_ACTIVITY_CLEAR_TOP
                intentBrowse.flags = flags
                context?.startActivity(intentBrowse)
            }
        }

        fun startActivityForResult(activity: Activity?, plugin: String, intent: Intent, requestCode: Int) {
            if (RewardSDK.mIsSingleApk) {
                activity?.startActivityForResult(intent, requestCode)
                return
            }

            var cn = intent.component
            cn = Factory.loadPluginActivity(intent, plugin, cn?.className, IPluginManager.PROCESS_AUTO)
            if (cn != null) {
                intent.component = cn
                activity?.startActivityForResult(intent, requestCode)
            } else {
                Logger.handleException(IllegalStateException("loadPluginActivity exception component null"))
            }
        }

        fun handleGo2DeepLink(context: Context?, deepLink: String?, deepLinkPkgName: String?): Boolean {
            var handled = false
            try {
                if (!TextUtils.isEmpty(deepLink)) {
                    val intent = Intent.parseUri(deepLink, 0)
                    intent.action = "android.intent.action.VIEW"
                    intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
                    if (!TextUtils.isEmpty(deepLinkPkgName)) {
                        intent.setPackage(deepLinkPkgName)
                    }
                    val res = context?.packageManager?.queryIntentActivities(intent,
                            PackageManager.MATCH_DEFAULT_ONLY)
                    if (res != null && res.size > 0) {
                        context.startActivity(intent)
                        handled = true
                    }
                }
            } catch (e: Exception) {
                Logger.handleException(e)
            }

            return handled
        }
    }


}
